SpillPolicy

Trait SpillPolicy 

pub trait SpillPolicy: Send {
    // Required method
    fn apply(&mut self, queue: &mut VecDeque<QueueEntry>);
}
Inspects and optionally rewrites a MergeQueue’s entries.

Required Methods

fn apply(&mut self, queue: &mut VecDeque<QueueEntry>)

Optionally transforms some (ranges of) queue entries.

This trait is used both for spilling and rehydrating, and just acts on the list of queue entries, rewriting ranges of them as it sees fit. This is intented for spilling data to secondary storage, but can also be used for compression, or other mechanisms to reduce resource load.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors