pub trait BytesSpill: Send {
// Required method
fn spill(
&mut self,
chunks: &mut Vec<Bytes>,
handles: &mut Vec<Box<dyn BytesFetch>>,
);
}Expand description
A type that can convert runs of bytes into runs of boxed bytes retrieval.
Required Methods
Sourcefn spill(
&mut self,
chunks: &mut Vec<Bytes>,
handles: &mut Vec<Box<dyn BytesFetch>>,
)
fn spill( &mut self, chunks: &mut Vec<Bytes>, handles: &mut Vec<Box<dyn BytesFetch>>, )
Move entries from chunks into handles, spilling each to backing storage.
The implementor should drain from chunks and push to handlesas it goes;
on failure it may stop partway, leaving the data in a consistent state that
will be retried in the future. If it cannot leave the lists in a consistent
state it should panic.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".